@@ -69,11 +69,10 @@ class FlashScopeTestCase(TestCase):
         self.assertFalse('error' in self.flash)
         self.assertEqual('Info', self.flash['info'])
 
-    def test_get_item(self):
-        """FlashScope: flash[key]" syntax should be supported.
+    def test_get_invalid_item(self):
+        """FlashScope: Should raise KeyError if trying to get an invalid value.
         """
         self.assertRaises(KeyError, lambda: self.flash['error']);
-        self.assertEqual('Info', self.flash['info']);
 
     def test_set_item(self):
         """FlashScope: flash[key] = value" syntax should be supported.
@@ -138,24 +137,36 @@ class FlashScopeTestCase(TestCase):
         self.assertRaises(StopIteration, iterator.next)
 
     def test_add_with_existing_non_list_value(self):
-        """FlashScope: Should add values to a key even if the current value is not a list.
+        """FlashScope: Should append a value to a key even if the current value is not a list.
         """
         self.flash.add('info', 'Error')
         self.assertEqual(['Info', 'Error'], self.flash['info'])
 
     def test_add_with_existing_list_value(self):
-        """FlashScope: Should add a new value if the current value is a list.
+        """FlashScope: Should append a value if the current value is a list.
         """
         self.flash['error'] = ['Error 1']
         self.flash.add('error', 'Error 2')
         self.assertEqual(['Error 1', 'Error 2'], self.flash['error'])
 
-    def test_add_with_no_existing_value(self):
+    def test_add_with_non_existing_value(self):
         """FlashScope: Should add a value even if the given key doesn't exists.
         """
         self.flash.add('error', 'Error')
         self.assertEqual(['Error'], self.flash['error'])
 
+    def test_add_across_requests(self):
+        """FlashScope: Should keep a key when a value is appended to it.
+        """
+        self.flash['error'] = 'Error 1'
+        self.flash.update()
+        self.flash.add('error', 'Error 2')
+        self.assertEqual(['Error 1', 'Error 2'], self.flash['error'])
+        self.flash.update()
+        self.assertEqual(['Error 1', 'Error 2'], self.flash['error'])
+        self.flash.update()
+        self.assertFalse('error' in self.flash)
+
     def test_get(self):
         """FlashScope: Should return a default value if the given key doesn' exists.
         """
@@ -164,41 +175,42 @@ class FlashScopeTestCase(TestCase):
         self.assertEqual(None, self.flash.get('error'))
 
     def test_pop(self):
-        """FlashScope: Should pop an item from the flash scope.
+        """FlashScope: Should pop a value from the flash scope.
         """
         self.assertEqual(None, self.flash.pop('error'))
         self.assertEqual('Info', self.flash.pop('info'))
         self.assertFalse('info' in self.flash)
 
     def test_pop_used_value(self):
-        """FlashScope: Should pop an used item from the flash scope.
+        """FlashScope: Should pop a used value from the flash scope.
         """
         self.flash.update()
         self.assertEqual('Info', self.flash.pop('info'))
         self.assertFalse('info' in self.flash)
 
-    def test_has_key(self):
-        """FlashScope: Should check if there's a value related with the given key.
-        """
-        self.assertFalse(self.flash.has_key('error'))
-        self.assertTrue(self.flash.has_key('info'))
-
     def test_put(self):
-        """FlashScope: Should put several values into the flash scope at the same time.
+        """FlashScope: Should put several keys into the flash scope at the same time.
         """
         self.flash.put(warn='Warning', error='Error')
         self.assertEqual('Warning', self.flash['warn'])
         self.assertEqual('Error', self.flash['error'])
 
+    def test_new_put(self):
+        """FlashScope: Should put several keys into the flash scope at the same time (new way).
+        """
+        self.flash(warn='Warning', error='Error')
+        self.assertEqual('Warning', self.flash['warn'])
+        self.assertEqual('Error', self.flash['error'])
+
     def test_discard(self):
-        """FlashScope: Should mark a flash-scoped value for removal.
+        """FlashScope: Should mark a value for removal.
         """
         self.flash.discard()
         self.flash.update()
         self.assertFalse('info' in self.flash)
 
     def test_keep(self):
-        """FlashScope: Should avoid the removal of specific flash-scoped values.
+        """FlashScope: Should avoid the removal of specific values.
         """
         self.flash.update()
         self.flash.keep('info')
@@ -208,7 +220,7 @@ class FlashScopeTestCase(TestCase):
         self.assertFalse('info' in self.flash)
 
     def test_keep_all(self):
-        """FlashScope: Should avoid the removal of all flash-scoped values.
+        """FlashScope: Should avoid the removal of all values.
         """
         self.flash.update()
         self.flash.keep()
@@ -217,37 +229,8 @@ class FlashScopeTestCase(TestCase):
         self.flash.update()
         self.assertFalse('info' in self.flash)
 
-    def test_alternative_now(self):
-        """FlashScope: Immediate values (flash.now) should be supported.
-        """
-        self.flash.now(error='Error')
-        self.assertEqual('Error', self.flash['error'])
-        self.flash.update()
-        self.assertFalse('error' in self.flash)
-
-    def test_now(self):
-        """FlashScope: "flash.now[key] = value" syntax should be supported.
-        """
-        self.flash.now['error'] = 'Error'
-        self.assertEqual('Error', self.flash['error'])
-        self.flash.update()
-        self.assertFalse('error' in self.flash)
-
-    def test_now_get_item(self):
-        """FlashScope: "FlashScope: "flash.now[key]" syntax should be supported.
-        """
-        self.flash.now['error'] = 'Error'
-        self.assertEqual('Error', self.flash.now['error'])
-
-    def test_now_contains(self):
-        """FlashScope: "key in flash.now" syntax should be supported.
-        """
-        self.assertFalse('error' in self.flash.now)
-        self.flash.now['error'] = 'Error'
-        self.assertTrue('error' in self.flash.now)
-
-    def test_replace_value(self):
-        """FlashScope: Should replace a value properly.
+    def test_replace_used_value(self):
+        """FlashScope: Should keep a key when its value is replaced.
         """
         self.flash.update()
         self.assertEqual('Info', self.flash['info'])
@@ -258,16 +241,6 @@ class FlashScopeTestCase(TestCase):
         self.flash.update()
         self.assertFalse('info' in self.flash)
 
-    def test_replace_with_immediage_value(self):
-        """FlashScope: Should replace a value properly by a immediate value.
-        """
-        self.flash.update()
-        self.assertEqual('Info', self.flash['info'])
-        self.flash.now['info'] = 'Error'
-        self.assertEqual('Error', self.flash['info'])
-        self.flash.update()
-        self.assertFalse('info' in self.flash)
-
     def test_empty_to_dict(self):
         """FlashScope: Should export the flash data to a dict even if it's empty.
         """
@@ -293,3 +266,133 @@ class FlashScopeTestCase(TestCase):
         data = self.flash.to_dict()
         del self.flash['info']
         self.assertEqual('Info', data[_SESSION_KEY]['info'])
+
+
+class ImmediateFlashScope(TestCase):
+    """Tests the ``Flashscope.now``.
+    """
+    def setUp(self):
+        """Create a FlashScope object to be used by the test methods.
+        """
+        self.flash = FlashScope()
+        self.flash.now['info'] = 'Info'
+
+    def test_now(self):
+        """FlashScope.now: "flash.now[key] = value" syntax should be supported.
+        """
+        self.assertEqual('Info', self.flash['info'])
+        self.flash.update()
+        self.assertFalse('info' in self.flash)
+
+    def test_alternative_now(self):
+        """FlashScope.now: Immediate values (flash.now) should be supported.
+        """
+        self.flash.now(error='Error')
+        self.assertEqual('Error', self.flash['error'])
+        self.flash.update()
+        self.assertFalse('error' in self.flash)
+
+    def test_contains(self):
+        """FlashScope.now: "key in flash.now" syntax should be supported.
+        """
+        self.assertFalse('error' in self.flash.now)
+        self.flash.now['error'] = 'Error'
+        self.assertTrue('error' in self.flash.now)
+
+    def test_get_invalid_item(self):
+        """FlashScope.now: Should raise KeyError if trying to get an invalid item.
+        """
+        self.assertRaises(KeyError, lambda: self.flash.now['error']);
+
+    def test_add_with_non_existing_value(self):
+        """FlashScope.now: Should append an immediate value even if the given key doesn't exists.
+        """
+        self.flash.now.add('error', 'Error 1')
+        self.flash.now.add('error', 'Error 2', 'Error 3')
+        self.assertEqual(['Error 1', 'Error 2', 'Error 3'], self.flash['error'])
+
+    def test_add_with_existing_non_list_value(self):
+        """FlashScope.now: Should append immediate values to a key even if the current value is not a list.
+        """
+        self.flash.now.add('info', 'Error 1')
+        self.flash.now.add('info', 'Error 2', 'Error 3')
+        self.assertEqual(['Info', 'Error 1', 'Error 2', 'Error 3'], self.flash['info'])
+
+    def test_add_with_existing_list_value(self):
+        """FlashScope.now: Should append an immediate value if the current value is a list.
+        """
+        self.flash.now['error'] = ['Error 1']
+        self.flash.now.add('error', 'Error 2')
+        self.flash.now.add('error', 'Error 3', 'Error 4')
+        self.assertEqual(['Error 1', 'Error 2', 'Error 3', 'Error 4'], self.flash['error'])
+
+
+class MixedFlashScope(TestCase):
+    """Tests mixing regular and immediate values.
+    """
+    def setUp(self):
+        """Create a FlashScope object to be used by the test methods.
+        """
+        self.flash = FlashScope()
+
+    def test_replace_with_immediate_value(self):
+        """FlashScope: Should replace a regular value by an immediate value.
+        """
+        self.flash['info'] = 'Info'
+        self.flash.update()
+        self.assertEqual('Info', self.flash['info'])
+        self.flash.now['info'] = 'Error'
+        self.assertEqual('Error', self.flash['info'])
+        self.flash.update()
+        self.assertFalse('info' in self.flash)
+
+    def test_replace_immediate_with_regular_value(self):
+        """FlashScope: Should replace an immediate value with a regular value.
+        """
+        self.flash.now['info'] = 'Info'
+        self.assertEqual('Info', self.flash['info'])
+        self.flash['info'] = 'Error'
+        self.flash.update()
+        self.assertEqual('Error', self.flash['info'])
+        self.flash.update()
+        self.assertFalse('info' in self.flash)
+
+    def test_add_immediate_with_existing_regular_value(self):
+        """FlashScope.now: Should add an immediate value to a regular key, expiring on the current request.
+        """
+        self.flash['error'] = 'Error 1'
+        self.flash.now.add('error', 'Error 2')
+        self.assertEqual(['Error 1', 'Error 2'], self.flash['error'])
+        self.flash.update()
+        self.assertFalse('error' in self.flash)
+
+    def test_add_immediate_with_existing_regular_list(self):
+        """FlashScope.now: Should add an immediate value to a regular list, expiring on the current request.
+        """
+        self.flash['error'] = ['Error 1']
+        self.flash.now.add('error', 'Error 2')
+        self.assertEqual(['Error 1', 'Error 2'], self.flash['error'])
+        self.flash.update()
+        self.assertFalse('error' in self.flash)
+
+    def test_add_regular_with_existing_immediate_value(self):
+        """FlashScope: Should add a regular value to an immediate key, expiring on the next request.
+        """
+        self.flash.now['error'] = 'Error 1'
+        self.flash.add('error', 'Error 2')
+        self.assertEqual(['Error 1', 'Error 2'], self.flash['error'])
+        self.flash.update()
+        self.assertEqual(['Error 1', 'Error 2'], self.flash['error'])
+        self.flash.update()
+        self.assertFalse('error' in self.flash)
+
+    def test_add_regular_with_existing_immediate_list(self):
+        """FlashScope: Should add a regular value to an immediate list, expiring on the next request.
+        """
+        self.flash.now['error'] = ['Error 1']
+        self.flash.add('error', 'Error 2')
+        self.assertEqual(['Error 1', 'Error 2'], self.flash['error'])
+        self.flash.update()
+        self.assertEqual(['Error 1', 'Error 2'], self.flash['error'])
+        self.flash.update()
+        self.assertFalse('error' in self.flash)
