@@ -5,9 +5,18 @@ import os
 DEBUG = True
 TEMPLATE_DEBUG = DEBUG
 
+# For Django < 1.2
 DATABASE_ENGINE = 'sqlite3'
 DATABASE_NAME = 'db'
 
+# For Django >= 1.2
+DATABASES = {
+    'default': {
+        'ENGINE':'django.db.backends.sqlite3',
+        'NAME': 'db'
+    }
+}
+
 SECRET_KEY = 'g9b@q$)=^xd2g@-7pg=j=h3*8+xd#hgn-9je@iq5_m#seg&d1y'
 
 MEDIA_URL = '/media/'
